## Convenience Function

::: gropt.solve
    options:
        heading_level: 3

## SolveResult

::: gropt.SolveResult
    options:
        filters: ["!^_"]
        heading_level: 3

## SolverGroptSDMM

::: gropt.SolverGroptSDMM
    options:
        filters: ["!^_"]
        heading_level: 3

## SolverOSQP

::: gropt.SolverOSQP
    options:
        filters: ["!^_"]
        heading_level: 3

## Equilibration

::: gropt.equilibrate
    options:
        heading_level: 3

::: gropt.estimate_row_col_norms
    options:
        heading_level: 3

::: gropt.rescale_eq_vecs
    options:
        heading_level: 3

::: gropt.estimate_spec_norm
    options:
        heading_level: 3

::: gropt.estimate_individual_spec_norm
    options:
        heading_level: 3
